@@ -434,8 +434,7 @@ spark_data_apply_mode <- function(options, mode) {
         invoke(options, "mode", mode)
       } else {
         stop("Unsupported type ", typeof(mode), " for mode parameter.")
-      }
-    )
+      })
   }
 
   options
@@ -466,10 +465,13 @@ spark_data_write_generic <- function(df,
     writeOptions[["url"]] <- NULL
     if (is.null(url)) stop("Option 'url' is expected while using jdbc")
 
-    properties <- invoke_new(sc, "java.util.Properties") %>|%
-      lapply(names(writeOptions), function(optionName) {
-        list("setProperty", optionName, as.character(writeOptions[[optionName]]))
-      })
+    properties <- invoke_static(
+      sc,
+      "sparklyr.Utils",
+      "setProperties",
+      as.list(names(writeOptions)),
+      unname(writeOptions)
+    )
 
     invoke(options, fileMethod, url, path, properties)
   }
@@ -610,6 +612,27 @@ spark_write_table.spark_jobj <- function(x,
 #'
 #' @family Spark serialization routines
 #'
+#' @examples
+#' \dontrun{
+#' sc <- spark_connect(
+#'   master = "local",
+#'   config = list(
+#'     `sparklyr.shell.driver-class-path` = "/usr/share/java/mysql-connector-java-8.0.25.jar"
+#'   )
+#' )
+#' spark_read_jdbc(
+#'   sc,
+#'   name = "my_sql_table",
+#'   options = list(
+#'     url = "jdbc:mysql://localhost:3306/my_sql_schema",
+#'     driver = "com.mysql.jdbc.Driver",
+#'     user = "me",
+#'     password = "******",
+#'     dbtable = "my_sql_table"
+#'   )
+#' )
+#' }
+#'
 #' @export
 spark_read_jdbc <- function(sc,
                             name,
@@ -640,11 +663,12 @@ spark_read_libsvm <- function(sc,
                               repartition = 0,
                               memory = TRUE,
                               overwrite = TRUE,
+                              options = list(),
                               ...) {
   c(name, path) %<-% spark_read_compat_param(sc, name, path)
   if (overwrite) spark_remove_table_if_exists(sc, name)
 
-  df <- spark_data_read_generic(sc, "libsvm", "format") %>%
+  df <- spark_data_read_generic(sc, "libsvm", "format", options) %>%
     invoke("load", spark_normalize_path(path))
   spark_partition_register_df(sc, df, name, repartition, memory)
 }
@@ -674,7 +698,16 @@ spark_read_source <- function(sc,
   if (overwrite) spark_remove_table_if_exists(sc, name)
 
   df_reader <- spark_data_read_generic(sc, source, "format", options, columns)
-  df <- if (is.null(path)) invoke(df_reader, "load") else invoke(df_reader, "load", spark_normalize_path(path))
+  df <- if (is.null(path)) {
+    invoke(df_reader, "load")
+  } else {
+    if (sc$method != "databricks-connect") {
+      # `path` refers to some remote file in 'databricks-connect' use case, so,
+      # it should not be normalized based on the local OS platform or filesystem
+      path <- spark_normalize_path(path)
+    }
+    invoke(df_reader, "load", path)
+  }
   spark_partition_register_df(sc, df, name, repartition, memory)
 }
 
@@ -690,13 +723,16 @@ spark_read_source <- function(sc,
 #' \dontrun{
 #' sc <- spark_connect(
 #'   master = "local",
-#'   config = list(sparklyr.shell.packages = "mysql:mysql-connector-java:5.1.44")
+#'   config = list(
+#'     `sparklyr.shell.driver-class-path` = "/usr/share/java/mysql-connector-java-8.0.25.jar"
+#'   )
 #' )
 #' spark_write_jdbc(
 #'   sdf_len(sc, 10),
 #'   name = "my_sql_table",
 #'   options = list(
 #'     url = "jdbc:mysql://localhost:3306/my_sql_schema",
+#'     driver = "com.mysql.jdbc.Driver",
 #'     user = "me",
 #'     password = "******",
 #'     dbtable = "my_sql_table"
@@ -1112,6 +1148,104 @@ spark_write_avro <- function(x,
   )
 }
 
+#' Read binary data into a Spark DataFrame.
+#'
+#' Read binary files within a directory and convert each file into a record
+#' within the resulting Spark dataframe. The output will be a Spark dataframe
+#' with the following columns and possibly partition columns:
+#'   \itemize{
+#'     \item{path: StringType}
+#'     \item{modificationTime: TimestampType}
+#'     \item{length: LongType}
+#'     \item{content: BinaryType}
+#'  }
+#'
+#' @inheritParams spark_read_csv
+#' @param dir Directory to read binary files from.
+#' @param path_glob_filter Glob pattern of binary files to be loaded
+#'   (e.g., "*.jpg").
+#' @param recursive_file_lookup If FALSE (default), then partition discovery
+#'   will be enabled (i.e., if a partition naming scheme is present, then
+#'   partitions specified by subdirectory names such as "date=2019-07-01" will
+#'   be created and files outside subdirectories following a partition naming
+#'   scheme will be ignored). If TRUE, then all nested directories will be
+#'   searched even if their names do not follow a partition naming scheme.
+#'
+#' @family Spark serialization routines
+#'
+#' @export
+spark_read_binary <- function(sc,
+                              name = NULL,
+                              dir = name,
+                              path_glob_filter = "*",
+                              recursive_file_lookup = FALSE,
+                              repartition = 0,
+                              memory = TRUE,
+                              overwrite = TRUE) {
+  if (spark_version(sc) < "3.0.0") {
+    stop("Binary file data source is only supported in Spark 3.0 or above.")
+  }
+
+  spark_read_source(
+    sc,
+    name = name,
+    path = dir,
+    source = "binaryFile",
+    options = list(
+      pathGlobFilter = path_glob_filter,
+      recursiveFileLookup = tolower(as.character(recursive_file_lookup))
+    ),
+    repartition = repartition,
+    memory = memory,
+    overwrite = overwrite
+  )
+}
+
+#' Read image data into a Spark DataFrame.
+#'
+#' Read image files within a directory and convert each file into a record
+#' within the resulting Spark dataframe. The output will be a Spark dataframe
+#' consisting of struct types containing the following attributes:
+#'   \itemize{
+#'     \item{origin: StringType}
+#'     \item{height: IntegerType}
+#'     \item{width: IntegerType}
+#'     \item{nChannels: IntegerType}
+#'     \item{mode: IntegerType}
+#'     \item{data: BinaryType}
+#'  }
+#'
+#' @inheritParams spark_read_csv
+#' @param dir Directory to read binary files from.
+#' @param drop_invalid Whether to drop files that are not valid images from the
+#'   result (default: TRUE).
+#'
+#' @family Spark serialization routines
+#'
+#' @export
+spark_read_image <- function(sc,
+                             name = NULL,
+                             dir = name,
+                             drop_invalid = TRUE,
+                             repartition = 0,
+                             memory = TRUE,
+                             overwrite = TRUE) {
+  if (spark_version(sc) < "2.4.0") {
+    stop("Image data source is only supported in Spark 2.4 or above.")
+  }
+
+  spark_read_source(
+    sc,
+    name = name,
+    path = dir,
+    source = "image",
+    options = list(dropInvalid = drop_invalid),
+    repartition = repartition,
+    memory = memory,
+    overwrite = overwrite
+  )
+}
+
 #' Read file(s) into a Spark DataFrame using a custom reader
 #'
 #' Run a custom R function on Spark workers to ingest data from one or more files
@@ -1180,12 +1314,20 @@ spark_read <- function(sc,
   )
 
   if (is.language(reader)) f <- rlang::as_closure(reader)
-  reader <- serialize(reader, NULL)
+  serializer <- spark_apply_serializer()
+  serialize_impl <- (
+    if (is.list(serializer)) {
+      serializer$serializer
+    } else {
+      serializer
+    })
+  deserializer <- spark_apply_deserializer()
+  reader <- serialize_impl(reader)
   worker_impl <- function(df, rdr) {
-    rdr <- unserialize(rdr)
+    rdr <- deserializer(rdr)
     do.call(rbind, lapply(df$path, function(path) rdr(path)))
   }
-  worker_impl <- serialize(worker_impl, NULL)
+  worker_impl <- serialize_impl(worker_impl)
 
   worker_port <- as.integer(
     spark_config_value(sc$config, "sparklyr.gateway.port", "8880")
@@ -1196,8 +1338,8 @@ spark_read <- function(sc,
 
   bundle_path <- get_spark_apply_bundle_path(sc, packages)
 
-  serialized_worker_context <- serialize(
-    list(column_types = list("character"), user_context = reader), NULL
+  serialized_worker_context <- serialize_impl(
+    list(column_types = list("character"), user_context = reader)
   )
 
   rdd <- invoke_static(
@@ -1219,7 +1361,9 @@ spark_read <- function(sc,
     new.env(),
     as.integer(60),
     serialized_worker_context,
-    new.env()
+    new.env(),
+    serialize(serializer, NULL),
+    serialize(deserializer, NULL)
   )
   rdd <- invoke(rdd, "cache")
   schema <- spark_schema_from_rdd(sc, rdd, columns)
