@@ -79,7 +79,11 @@ summarise.tbl_spark <- function(.data, ...) {
   # `summarise(across(where(is.numeric), mean))` work as expected for Spark
   # dataframes
   dots <- rlang::quos(..., .named = TRUE)
-  dots <- partial_eval_dots(dots, sim_data = simulate_vars(.data))
+  dots <- dots %>% partial_eval_dots(
+    sim_data = simulate_vars(.data),
+    ctx = "summarize",
+    supports_one_sided_formula = FALSE
+  )
 
   # For each expression, check if it uses any newly created variables
   check_summarise_vars <- function(dots) {
@@ -214,7 +218,7 @@ spark_sql_translation <- function(con) {
     )
   }
 
-  dbplyr::sql_variant(
+  sparklyr_base_sql_variant <- list(
     scalar = dbplyr::sql_translator(
       .parent = dbplyr::base_scalar,
       as.numeric = function(x) dbplyr::build_sql("CAST(", x, " AS DOUBLE)"),
@@ -417,6 +421,30 @@ spark_sql_translation <- function(con) {
       }
     )
   )
+
+  dbplyr::sql_variant(
+    scalar = do.call(
+      dbplyr::sql_translator,
+      append(
+        list(.parent = sparklyr_base_sql_variant$scalar),
+        con$extensions$dbplyr_sql_variant$scalar
+      )
+    ),
+    aggregate = do.call(
+      dbplyr::sql_translator,
+      append(
+        list(.parent = sparklyr_base_sql_variant$aggregate),
+        con$extensions$dbplyr_sql_variant$aggregate
+      )
+    ),
+    window = do.call(
+      dbplyr::sql_translator,
+      append(
+        list(.parent = sparklyr_base_sql_variant$window),
+        con$extensions$dbplyr_sql_variant$window
+      )
+    )
+  )
 }
 
 build_sql_fn <- function(fn) {
